@@ -251,6 +251,48 @@ class IGBusinessUser(BaseResource):
         else:
             return IgBusMediaResponse.new_from_json_dict(data)
 
+    def get_live_media(
+        self,
+        fields: Optional[Union[str, list, tuple]] = None,
+        since: Optional[str] = None,
+        until: Optional[str] = None,
+        count: Optional[int] = 10,
+        limit: Optional[int] = 10,
+        return_json=False,
+    ) -> Union[IgBusMediaResponse, dict]:
+        """
+        Represents a collection of live video IG Media on an IG User.
+        Only live video IG Media being broadcast at the time of the request will be returned.
+
+        :param fields: Comma-separated id string for data fields which you want.
+            You can also pass this with an id list, tuple.
+        :param since: A Unix timestamp or strtotime data value that points to the start of data.
+        :param until: A Unix timestamp or strtotime data value that points to the end of data.
+        :param count: The total count for you to get data.
+        :param limit: Each request retrieve objects count.
+            It should no more than 100. Default is None will use api default limit.
+        :param return_json: Set to false will return a dataclass for IgBusMediaResponse.
+            Or return json data. Default is false.
+        :return: Media response information.
+        """
+
+        if fields is None:
+            fields = const.IG_BUSINESS_MEDIA_PUBLIC_FIELDS
+
+        data = self.client.get_full_connections(
+            object_id=self.client.instagram_business_id,
+            connection="live_media",
+            count=count,
+            limit=limit,
+            fields=enf_comma_separated(field="fields", value=fields),
+            since=since,
+            until=until,
+        )
+        if return_json:
+            return data
+        else:
+            return IgBusMediaResponse.new_from_json_dict(data)
+
     def get_mentioned_comment(
         self,
         comment_id: str,
